Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/moses-smt/mosesdecoder.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/moses/FF
diff options
context:
space:
mode:
authorHieu Hoang <hieuhoang@gmail.com>2015-11-03 12:41:59 +0300
committerHieu Hoang <hieuhoang@gmail.com>2015-11-03 12:41:59 +0300
commit6be932c1f75a9ca171336a253f0f64659a30fa1a (patch)
tree1e6cea036afe088022f0749c8eef2055f5a63789 /moses/FF
parentee5b190d43719752a58de6280266b2c2f497e35c (diff)
consistent naming of future scores, estimated scores
Diffstat (limited to 'moses/FF')
-rw-r--r--moses/FF/BleuScoreFeature.h4
-rw-r--r--moses/FF/ConstrainedDecoding.h4
-rw-r--r--moses/FF/ControlRecombination.h4
-rw-r--r--moses/FF/CountNonTerms.cpp2
-rw-r--r--moses/FF/CountNonTerms.h4
-rw-r--r--moses/FF/CoveredReferenceFeature.cpp6
-rw-r--r--moses/FF/CoveredReferenceFeature.h4
-rw-r--r--moses/FF/DecodeFeature.h4
-rw-r--r--moses/FF/DeleteRules.cpp4
-rw-r--r--moses/FF/DeleteRules.h4
-rw-r--r--moses/FF/DistortionScoreProducer.h4
-rw-r--r--moses/FF/DynamicCacheBasedLanguageModel.cpp2
-rw-r--r--moses/FF/DynamicCacheBasedLanguageModel.h4
-rw-r--r--moses/FF/FeatureFunction.h8
-rw-r--r--moses/FF/GlobalLexicalModel.cpp2
-rw-r--r--moses/FF/GlobalLexicalModel.h4
-rw-r--r--moses/FF/GlobalLexicalModelUnlimited.h4
-rw-r--r--moses/FF/HyperParameterAsWeight.h4
-rw-r--r--moses/FF/InputFeature.cpp2
-rw-r--r--moses/FF/InputFeature.h4
-rw-r--r--moses/FF/LexicalReordering/LexicalReordering.h4
-rw-r--r--moses/FF/MaxSpanFreeNonTermSource.cpp4
-rw-r--r--moses/FF/MaxSpanFreeNonTermSource.h4
-rw-r--r--moses/FF/Model1Feature.cpp2
-rw-r--r--moses/FF/Model1Feature.h4
-rw-r--r--moses/FF/NieceTerminal.cpp4
-rw-r--r--moses/FF/NieceTerminal.h4
-rw-r--r--moses/FF/OSM-Feature/OpSequenceModel.cpp4
-rw-r--r--moses/FF/OSM-Feature/OpSequenceModel.h4
-rw-r--r--moses/FF/PhraseBoundaryFeature.h4
-rw-r--r--moses/FF/PhraseLengthFeature.cpp2
-rw-r--r--moses/FF/PhraseLengthFeature.h4
-rw-r--r--moses/FF/PhraseOrientationFeature.cpp2
-rw-r--r--moses/FF/PhraseOrientationFeature.h4
-rw-r--r--moses/FF/PhrasePairFeature.cpp4
-rw-r--r--moses/FF/PhrasePairFeature.h4
-rw-r--r--moses/FF/PhrasePenalty.cpp2
-rw-r--r--moses/FF/PhrasePenalty.h4
-rw-r--r--moses/FF/ReferenceComparison.h4
-rw-r--r--moses/FF/RulePairUnlexicalizedSource.cpp2
-rw-r--r--moses/FF/RulePairUnlexicalizedSource.h4
-rw-r--r--moses/FF/RuleScope.cpp6
-rw-r--r--moses/FF/RuleScope.h4
-rw-r--r--moses/FF/SetSourcePhrase.cpp2
-rw-r--r--moses/FF/SetSourcePhrase.h4
-rw-r--r--moses/FF/SkeletonStatefulFF.cpp4
-rw-r--r--moses/FF/SkeletonStatefulFF.h4
-rw-r--r--moses/FF/SkeletonStatelessFF.cpp4
-rw-r--r--moses/FF/SkeletonStatelessFF.h4
-rw-r--r--moses/FF/SoftMatchingFeature.h4
-rw-r--r--moses/FF/SoftSourceSyntacticConstraintsFeature.cpp2
-rw-r--r--moses/FF/SoftSourceSyntacticConstraintsFeature.h4
-rw-r--r--moses/FF/SourceGHKMTreeInputMatchFeature.cpp2
-rw-r--r--moses/FF/SourceGHKMTreeInputMatchFeature.h4
-rw-r--r--moses/FF/SourceWordDeletionFeature.cpp2
-rw-r--r--moses/FF/SourceWordDeletionFeature.h4
-rw-r--r--moses/FF/SpanLength.cpp4
-rw-r--r--moses/FF/SpanLength.h4
-rw-r--r--moses/FF/SparseHieroReorderingFeature.h4
-rw-r--r--moses/FF/SyntaxRHS.cpp4
-rw-r--r--moses/FF/SyntaxRHS.h4
-rw-r--r--moses/FF/TargetBigramFeature.h4
-rw-r--r--moses/FF/TargetNgramFeature.h4
-rw-r--r--moses/FF/TargetWordInsertionFeature.cpp2
-rw-r--r--moses/FF/TargetWordInsertionFeature.h4
-rw-r--r--moses/FF/TreeStructureFeature.h4
-rw-r--r--moses/FF/UnalignedWordCountFeature.cpp2
-rw-r--r--moses/FF/UnalignedWordCountFeature.h4
-rw-r--r--moses/FF/UnknownWordPenaltyProducer.h4
-rw-r--r--moses/FF/WordPenaltyProducer.cpp2
-rw-r--r--moses/FF/WordPenaltyProducer.h4
-rw-r--r--moses/FF/WordTranslationFeature.cpp2
-rw-r--r--moses/FF/WordTranslationFeature.h4
73 files changed, 133 insertions, 133 deletions
diff --git a/moses/FF/BleuScoreFeature.h b/moses/FF/BleuScoreFeature.h
index 50984a71f..c827c5c65 100644
--- a/moses/FF/BleuScoreFeature.h
+++ b/moses/FF/BleuScoreFeature.h
@@ -128,7 +128,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -137,7 +137,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
bool Enabled() const {
diff --git a/moses/FF/ConstrainedDecoding.h b/moses/FF/ConstrainedDecoding.h
index d3c5713d3..e0d4cdff3 100644
--- a/moses/FF/ConstrainedDecoding.h
+++ b/moses/FF/ConstrainedDecoding.h
@@ -45,7 +45,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
void EvaluateWithSourceContext(const InputType &input
@@ -53,7 +53,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/ControlRecombination.h b/moses/FF/ControlRecombination.h
index 106e8a4bc..a75fabb5d 100644
--- a/moses/FF/ControlRecombination.h
+++ b/moses/FF/ControlRecombination.h
@@ -61,14 +61,14 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/CountNonTerms.cpp b/moses/FF/CountNonTerms.cpp
index 07549942e..4e020153e 100644
--- a/moses/FF/CountNonTerms.cpp
+++ b/moses/FF/CountNonTerms.cpp
@@ -19,7 +19,7 @@ CountNonTerms::CountNonTerms(const std::string &line)
void CountNonTerms::EvaluateInIsolation(const Phrase &sourcePhrase
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
const StaticData &staticData = StaticData::Instance();
diff --git a/moses/FF/CountNonTerms.h b/moses/FF/CountNonTerms.h
index 2e29f2aaa..a8b836748 100644
--- a/moses/FF/CountNonTerms.h
+++ b/moses/FF/CountNonTerms.h
@@ -16,14 +16,14 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/CoveredReferenceFeature.cpp b/moses/FF/CoveredReferenceFeature.cpp
index 94c6e9c12..48faded35 100644
--- a/moses/FF/CoveredReferenceFeature.cpp
+++ b/moses/FF/CoveredReferenceFeature.cpp
@@ -33,7 +33,7 @@ bool CoveredReferenceState::operator==(const FFState& other) const
void CoveredReferenceFeature::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{}
void CoveredReferenceFeature::EvaluateWithSourceContext(const InputType &input
@@ -41,7 +41,7 @@ void CoveredReferenceFeature::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore) const
+ , ScoreComponentCollection *estimatedScore) const
{
long id = input.GetTranslationId();
boost::unordered_map<long, std::multiset<string> >::const_iterator refIt = m_refs.find(id);
@@ -54,7 +54,7 @@ void CoveredReferenceFeature::EvaluateWithSourceContext(const InputType &input
scores.push_back(covered.size());
scoreBreakdown.Assign(this, scores);
- estimatedFutureScore->Assign(this, scores);
+ estimatedScore->Assign(this, scores);
}
void CoveredReferenceFeature::Load()
diff --git a/moses/FF/CoveredReferenceFeature.h b/moses/FF/CoveredReferenceFeature.h
index e45f234ae..fb5ab7e15 100644
--- a/moses/FF/CoveredReferenceFeature.h
+++ b/moses/FF/CoveredReferenceFeature.h
@@ -56,13 +56,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const;
+ , ScoreComponentCollection *estimatedScore = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/DecodeFeature.h b/moses/FF/DecodeFeature.h
index fdc1460bc..a1a38de36 100644
--- a/moses/FF/DecodeFeature.h
+++ b/moses/FF/DecodeFeature.h
@@ -76,7 +76,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
@@ -85,7 +85,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
void SetContainer(const DecodeStep *container) {
diff --git a/moses/FF/DeleteRules.cpp b/moses/FF/DeleteRules.cpp
index 96bb07c58..b72f695f7 100644
--- a/moses/FF/DeleteRules.cpp
+++ b/moses/FF/DeleteRules.cpp
@@ -41,7 +41,7 @@ void DeleteRules::Load()
void DeleteRules::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &target
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
// dense scores
size_t hash = 0;
@@ -61,7 +61,7 @@ void DeleteRules::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore) const
+ , ScoreComponentCollection *estimatedScore) const
{}
void DeleteRules::EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/DeleteRules.h b/moses/FF/DeleteRules.h
index d02490369..754b9a241 100644
--- a/moses/FF/DeleteRules.h
+++ b/moses/FF/DeleteRules.h
@@ -24,13 +24,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const;
+ , ScoreComponentCollection *estimatedScore = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const;
diff --git a/moses/FF/DistortionScoreProducer.h b/moses/FF/DistortionScoreProducer.h
index a7cd6f36a..ed8a2e6ce 100644
--- a/moses/FF/DistortionScoreProducer.h
+++ b/moses/FF/DistortionScoreProducer.h
@@ -52,7 +52,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -62,7 +62,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
};
}
diff --git a/moses/FF/DynamicCacheBasedLanguageModel.cpp b/moses/FF/DynamicCacheBasedLanguageModel.cpp
index f4e98b3c5..8ba4798fd 100644
--- a/moses/FF/DynamicCacheBasedLanguageModel.cpp
+++ b/moses/FF/DynamicCacheBasedLanguageModel.cpp
@@ -88,7 +88,7 @@ void DynamicCacheBasedLanguageModel::SetParameter(const std::string& key, const
void DynamicCacheBasedLanguageModel::EvaluateInIsolation(const Phrase &sp
, const TargetPhrase &tp
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
float score = m_lower_score;
switch(m_query_type) {
diff --git a/moses/FF/DynamicCacheBasedLanguageModel.h b/moses/FF/DynamicCacheBasedLanguageModel.h
index 39e102e10..3f53a7d76 100644
--- a/moses/FF/DynamicCacheBasedLanguageModel.h
+++ b/moses/FF/DynamicCacheBasedLanguageModel.h
@@ -132,14 +132,14 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/GlobalLexicalModel.cpp b/moses/FF/GlobalLexicalModel.cpp
index 571e49a33..7da3679b7 100644
--- a/moses/FF/GlobalLexicalModel.cpp
+++ b/moses/FF/GlobalLexicalModel.cpp
@@ -171,7 +171,7 @@ float GlobalLexicalModel::GetFromCacheOrScorePhrase( const TargetPhrase& targetP
void GlobalLexicalModel::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
scoreBreakdown.PlusEquals( this, GetFromCacheOrScorePhrase(targetPhrase) );
}
diff --git a/moses/FF/GlobalLexicalModel.h b/moses/FF/GlobalLexicalModel.h
index 17f905440..7038fb451 100644
--- a/moses/FF/GlobalLexicalModel.h
+++ b/moses/FF/GlobalLexicalModel.h
@@ -75,7 +75,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWhenApplied(const Hypothesis& hypo,
ScoreComponentCollection* accumulator) const {
@@ -89,7 +89,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/GlobalLexicalModelUnlimited.h b/moses/FF/GlobalLexicalModelUnlimited.h
index ece01bfa1..647b81dfe 100644
--- a/moses/FF/GlobalLexicalModelUnlimited.h
+++ b/moses/FF/GlobalLexicalModelUnlimited.h
@@ -90,7 +90,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -100,7 +100,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
void AddFeature(ScoreComponentCollection* accumulator,
diff --git a/moses/FF/HyperParameterAsWeight.h b/moses/FF/HyperParameterAsWeight.h
index cd8d66821..6815b5a64 100644
--- a/moses/FF/HyperParameterAsWeight.h
+++ b/moses/FF/HyperParameterAsWeight.h
@@ -21,7 +21,7 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
virtual void EvaluateWithSourceContext(const InputType &input
@@ -29,7 +29,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
virtual void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/InputFeature.cpp b/moses/FF/InputFeature.cpp
index 6acb432ff..902ba64fc 100644
--- a/moses/FF/InputFeature.cpp
+++ b/moses/FF/InputFeature.cpp
@@ -49,7 +49,7 @@ void InputFeature::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore) const
+ , ScoreComponentCollection *estimatedScore) const
{
if (m_legacy) {
//binary phrase-table does input feature itself
diff --git a/moses/FF/InputFeature.h b/moses/FF/InputFeature.h
index 1815cd8f4..f03af98e8 100644
--- a/moses/FF/InputFeature.h
+++ b/moses/FF/InputFeature.h
@@ -41,7 +41,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
void EvaluateWithSourceContext(const InputType &input
@@ -49,7 +49,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const;
+ , ScoreComponentCollection *estimatedScore = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/LexicalReordering/LexicalReordering.h b/moses/FF/LexicalReordering/LexicalReordering.h
index 33e4a66ae..e7b90afda 100644
--- a/moses/FF/LexicalReordering/LexicalReordering.h
+++ b/moses/FF/LexicalReordering/LexicalReordering.h
@@ -71,7 +71,7 @@ public:
const TargetPhrase &targetPhrase,
const StackVec *stackVec,
ScoreComponentCollection& scoreBreakdown,
- ScoreComponentCollection* estimatedFutureScore = NULL) const
+ ScoreComponentCollection* estimatedScore = NULL) const
{ }
void
@@ -83,7 +83,7 @@ public:
EvaluateInIsolation(const Phrase &source,
const TargetPhrase &targetPhrase,
ScoreComponentCollection &scoreBreakdown,
- ScoreComponentCollection &estimatedFutureScore) const
+ ScoreComponentCollection &estimatedScore) const
{ }
bool
diff --git a/moses/FF/MaxSpanFreeNonTermSource.cpp b/moses/FF/MaxSpanFreeNonTermSource.cpp
index 2e0d6fa4d..f1ac39633 100644
--- a/moses/FF/MaxSpanFreeNonTermSource.cpp
+++ b/moses/FF/MaxSpanFreeNonTermSource.cpp
@@ -30,7 +30,7 @@ MaxSpanFreeNonTermSource::MaxSpanFreeNonTermSource(const std::string &line)
void MaxSpanFreeNonTermSource::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
targetPhrase.SetRuleSource(source);
}
@@ -40,7 +40,7 @@ void MaxSpanFreeNonTermSource::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore) const
+ , ScoreComponentCollection *estimatedScore) const
{
const Word &targetLHS = targetPhrase.GetTargetLHS();
diff --git a/moses/FF/MaxSpanFreeNonTermSource.h b/moses/FF/MaxSpanFreeNonTermSource.h
index 411b2d51d..96f6682d8 100644
--- a/moses/FF/MaxSpanFreeNonTermSource.h
+++ b/moses/FF/MaxSpanFreeNonTermSource.h
@@ -19,14 +19,14 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
virtual void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const;
+ , ScoreComponentCollection *estimatedScore = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/Model1Feature.cpp b/moses/FF/Model1Feature.cpp
index 7ea7cd651..d14e2e1bb 100644
--- a/moses/FF/Model1Feature.cpp
+++ b/moses/FF/Model1Feature.cpp
@@ -183,7 +183,7 @@ void Model1Feature::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore) const
+ , ScoreComponentCollection *estimatedScore) const
{
const Sentence& sentence = static_cast<const Sentence&>(input);
float score = 0.0;
diff --git a/moses/FF/Model1Feature.h b/moses/FF/Model1Feature.h
index 610a39808..ba192b1e7 100644
--- a/moses/FF/Model1Feature.h
+++ b/moses/FF/Model1Feature.h
@@ -66,7 +66,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{};
void EvaluateWithSourceContext(const InputType &input
@@ -74,7 +74,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const;
+ , ScoreComponentCollection *estimatedScore = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const
diff --git a/moses/FF/NieceTerminal.cpp b/moses/FF/NieceTerminal.cpp
index c1e454124..50f3b9a5c 100644
--- a/moses/FF/NieceTerminal.cpp
+++ b/moses/FF/NieceTerminal.cpp
@@ -27,7 +27,7 @@ std::vector<float> NieceTerminal::DefaultWeights() const
void NieceTerminal::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
targetPhrase.SetRuleSource(source);
}
@@ -37,7 +37,7 @@ void NieceTerminal::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore) const
+ , ScoreComponentCollection *estimatedScore) const
{
assert(stackVec);
diff --git a/moses/FF/NieceTerminal.h b/moses/FF/NieceTerminal.h
index 1b1c0df80..71e61fc67 100644
--- a/moses/FF/NieceTerminal.h
+++ b/moses/FF/NieceTerminal.h
@@ -22,13 +22,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const;
+ , ScoreComponentCollection *estimatedScore = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/OSM-Feature/OpSequenceModel.cpp b/moses/FF/OSM-Feature/OpSequenceModel.cpp
index 8153debbd..4d9d6b44f 100644
--- a/moses/FF/OSM-Feature/OpSequenceModel.cpp
+++ b/moses/FF/OSM-Feature/OpSequenceModel.cpp
@@ -45,7 +45,7 @@ void OpSequenceModel::Load()
void OpSequenceModel:: EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
osmHypothesis obj;
@@ -82,7 +82,7 @@ void OpSequenceModel:: EvaluateInIsolation(const Phrase &source
obj.computeOSMFeature(startIndex,myBitmap);
obj.calculateOSMProb(*OSM);
obj.populateScores(scores,numFeatures);
- estimatedFutureScore.PlusEquals(this, scores);
+ estimatedScore.PlusEquals(this, scores);
}
diff --git a/moses/FF/OSM-Feature/OpSequenceModel.h b/moses/FF/OSM-Feature/OpSequenceModel.h
index b59eb681a..889a3807e 100644
--- a/moses/FF/OSM-Feature/OpSequenceModel.h
+++ b/moses/FF/OSM-Feature/OpSequenceModel.h
@@ -42,7 +42,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -52,7 +52,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
virtual const FFState* EmptyHypothesisState(const InputType &input) const;
diff --git a/moses/FF/PhraseBoundaryFeature.h b/moses/FF/PhraseBoundaryFeature.h
index 56189d446..e7669ee20 100644
--- a/moses/FF/PhraseBoundaryFeature.h
+++ b/moses/FF/PhraseBoundaryFeature.h
@@ -59,7 +59,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -68,7 +68,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
void SetParameter(const std::string& key, const std::string& value);
diff --git a/moses/FF/PhraseLengthFeature.cpp b/moses/FF/PhraseLengthFeature.cpp
index 9dbb0235e..91d5b0c5a 100644
--- a/moses/FF/PhraseLengthFeature.cpp
+++ b/moses/FF/PhraseLengthFeature.cpp
@@ -19,7 +19,7 @@ PhraseLengthFeature::PhraseLengthFeature(const std::string &line)
void PhraseLengthFeature::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
// get length of source and target phrase
size_t targetLength = targetPhrase.GetSize();
diff --git a/moses/FF/PhraseLengthFeature.h b/moses/FF/PhraseLengthFeature.h
index 9ff36750c..9f05e25a1 100644
--- a/moses/FF/PhraseLengthFeature.h
+++ b/moses/FF/PhraseLengthFeature.h
@@ -36,7 +36,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -45,7 +45,7 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
};
diff --git a/moses/FF/PhraseOrientationFeature.cpp b/moses/FF/PhraseOrientationFeature.cpp
index e88e80769..ab6f52976 100644
--- a/moses/FF/PhraseOrientationFeature.cpp
+++ b/moses/FF/PhraseOrientationFeature.cpp
@@ -109,7 +109,7 @@ void PhraseOrientationFeature::LoadWordList(const std::string& filename,
void PhraseOrientationFeature::EvaluateInIsolation(const Phrase &source,
const TargetPhrase &targetPhrase,
ScoreComponentCollection &scoreBreakdown,
- ScoreComponentCollection &estimatedFutureScore) const
+ ScoreComponentCollection &estimatedScore) const
{
targetPhrase.SetRuleSource(source);
diff --git a/moses/FF/PhraseOrientationFeature.h b/moses/FF/PhraseOrientationFeature.h
index 786a632fa..25977468c 100644
--- a/moses/FF/PhraseOrientationFeature.h
+++ b/moses/FF/PhraseOrientationFeature.h
@@ -294,14 +294,14 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const
+ , ScoreComponentCollection *estimatedScore = NULL) const
{};
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/PhrasePairFeature.cpp b/moses/FF/PhrasePairFeature.cpp
index d531d9a54..99d141c30 100644
--- a/moses/FF/PhrasePairFeature.cpp
+++ b/moses/FF/PhrasePairFeature.cpp
@@ -118,7 +118,7 @@ void PhrasePairFeature::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore) const
+ , ScoreComponentCollection *estimatedScore) const
{
const Phrase& source = inputPath.GetPhrase();
if (m_domainTrigger) {
@@ -237,7 +237,7 @@ void PhrasePairFeature::EvaluateWithSourceContext(const InputType &input
void PhrasePairFeature::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
if (m_simple) {
util::StringStream namestr;
diff --git a/moses/FF/PhrasePairFeature.h b/moses/FF/PhrasePairFeature.h
index 4d0e76f9f..d2a427b47 100644
--- a/moses/FF/PhrasePairFeature.h
+++ b/moses/FF/PhrasePairFeature.h
@@ -52,7 +52,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
@@ -62,7 +62,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const;
+ , ScoreComponentCollection *estimatedScore = NULL) const;
void EvaluateWhenApplied(const Hypothesis& hypo,
ScoreComponentCollection* accumulator) const {
diff --git a/moses/FF/PhrasePenalty.cpp b/moses/FF/PhrasePenalty.cpp
index e4ee294fa..5e0d932ba 100644
--- a/moses/FF/PhrasePenalty.cpp
+++ b/moses/FF/PhrasePenalty.cpp
@@ -18,7 +18,7 @@ PhrasePenalty::PhrasePenalty(const std::string &line)
void PhrasePenalty::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
if (m_perPhraseTable) {
const PhraseDictionary *pt = targetPhrase.GetContainer();
diff --git a/moses/FF/PhrasePenalty.h b/moses/FF/PhrasePenalty.h
index 044184755..020161956 100644
--- a/moses/FF/PhrasePenalty.h
+++ b/moses/FF/PhrasePenalty.h
@@ -17,7 +17,7 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWhenApplied(const Hypothesis& hypo,
ScoreComponentCollection* accumulator) const {
@@ -34,7 +34,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/ReferenceComparison.h b/moses/FF/ReferenceComparison.h
index c28cdc5d7..917b6964d 100644
--- a/moses/FF/ReferenceComparison.h
+++ b/moses/FF/ReferenceComparison.h
@@ -19,7 +19,7 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
virtual void EvaluateWithSourceContext(const InputType &input
@@ -27,7 +27,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/RulePairUnlexicalizedSource.cpp b/moses/FF/RulePairUnlexicalizedSource.cpp
index fe1a4f648..102ab0733 100644
--- a/moses/FF/RulePairUnlexicalizedSource.cpp
+++ b/moses/FF/RulePairUnlexicalizedSource.cpp
@@ -41,7 +41,7 @@ void RulePairUnlexicalizedSource::SetParameter(const std::string& key, const std
void RulePairUnlexicalizedSource::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
const Factor* targetPhraseLHS = targetPhrase.GetTargetLHS()[0];
if ( !m_glueRules && (targetPhraseLHS == m_glueTargetLHS) ) {
diff --git a/moses/FF/RulePairUnlexicalizedSource.h b/moses/FF/RulePairUnlexicalizedSource.h
index e8f7f0d9b..e6a3c62fa 100644
--- a/moses/FF/RulePairUnlexicalizedSource.h
+++ b/moses/FF/RulePairUnlexicalizedSource.h
@@ -24,14 +24,14 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const
+ , ScoreComponentCollection *estimatedScore = NULL) const
{}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/RuleScope.cpp b/moses/FF/RuleScope.cpp
index c894a2b20..3f040c2ee 100644
--- a/moses/FF/RuleScope.cpp
+++ b/moses/FF/RuleScope.cpp
@@ -23,7 +23,7 @@ bool IsAmbiguous(const Word &word, bool sourceSyntax)
void RuleScope::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
if (IsGlueRule(source)) {
return;
@@ -67,12 +67,12 @@ void RuleScope::EvaluateInIsolation(const Phrase &source
scores[score] = 1;
if (m_futureCostOnly) {
- estimatedFutureScore.PlusEquals(this, scores);
+ estimatedScore.PlusEquals(this, scores);
} else {
scoreBreakdown.PlusEquals(this, scores);
}
} else if (m_futureCostOnly) {
- estimatedFutureScore.PlusEquals(this, score);
+ estimatedScore.PlusEquals(this, score);
} else {
scoreBreakdown.PlusEquals(this, score);
}
diff --git a/moses/FF/RuleScope.h b/moses/FF/RuleScope.h
index 113ca8be7..87099dac3 100644
--- a/moses/FF/RuleScope.h
+++ b/moses/FF/RuleScope.h
@@ -18,14 +18,14 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
virtual void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/SetSourcePhrase.cpp b/moses/FF/SetSourcePhrase.cpp
index 115affa52..9c5f3b07a 100644
--- a/moses/FF/SetSourcePhrase.cpp
+++ b/moses/FF/SetSourcePhrase.cpp
@@ -13,7 +13,7 @@ SetSourcePhrase::SetSourcePhrase(const std::string &line)
void SetSourcePhrase::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
targetPhrase.SetRuleSource(source);
}
diff --git a/moses/FF/SetSourcePhrase.h b/moses/FF/SetSourcePhrase.h
index e34e618f2..fc965685f 100644
--- a/moses/FF/SetSourcePhrase.h
+++ b/moses/FF/SetSourcePhrase.h
@@ -18,14 +18,14 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
virtual void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/SkeletonStatefulFF.cpp b/moses/FF/SkeletonStatefulFF.cpp
index 1bcf65fb1..e44823bbd 100644
--- a/moses/FF/SkeletonStatefulFF.cpp
+++ b/moses/FF/SkeletonStatefulFF.cpp
@@ -18,7 +18,7 @@ SkeletonStatefulFF::SkeletonStatefulFF(const std::string &line)
void SkeletonStatefulFF::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{}
void SkeletonStatefulFF::EvaluateWithSourceContext(const InputType &input
@@ -26,7 +26,7 @@ void SkeletonStatefulFF::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore) const
+ , ScoreComponentCollection *estimatedScore) const
{}
void SkeletonStatefulFF::EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/SkeletonStatefulFF.h b/moses/FF/SkeletonStatefulFF.h
index 20160cf7f..c861abbdf 100644
--- a/moses/FF/SkeletonStatefulFF.h
+++ b/moses/FF/SkeletonStatefulFF.h
@@ -40,13 +40,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const;
+ , ScoreComponentCollection *estimatedScore = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const;
diff --git a/moses/FF/SkeletonStatelessFF.cpp b/moses/FF/SkeletonStatelessFF.cpp
index 209409a8e..d75ae8047 100644
--- a/moses/FF/SkeletonStatelessFF.cpp
+++ b/moses/FF/SkeletonStatelessFF.cpp
@@ -16,7 +16,7 @@ SkeletonStatelessFF::SkeletonStatelessFF(const std::string &line)
void SkeletonStatelessFF::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
// dense scores
vector<float> newScores(m_numScoreComponents);
@@ -34,7 +34,7 @@ void SkeletonStatelessFF::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore) const
+ , ScoreComponentCollection *estimatedScore) const
{
if (targetPhrase.GetNumNonTerminals()) {
vector<float> newScores(m_numScoreComponents);
diff --git a/moses/FF/SkeletonStatelessFF.h b/moses/FF/SkeletonStatelessFF.h
index 7fb6634c2..b5ef03df8 100644
--- a/moses/FF/SkeletonStatelessFF.h
+++ b/moses/FF/SkeletonStatelessFF.h
@@ -18,13 +18,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const;
+ , ScoreComponentCollection *estimatedScore = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const;
diff --git a/moses/FF/SoftMatchingFeature.h b/moses/FF/SoftMatchingFeature.h
index 7bdcc7717..4b270008b 100644
--- a/moses/FF/SoftMatchingFeature.h
+++ b/moses/FF/SoftMatchingFeature.h
@@ -25,13 +25,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {};
+ , ScoreComponentCollection &estimatedScore) const {};
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {};
+ , ScoreComponentCollection *estimatedScore = NULL) const {};
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/SoftSourceSyntacticConstraintsFeature.cpp b/moses/FF/SoftSourceSyntacticConstraintsFeature.cpp
index 322e95ab2..9a0a1dddf 100644
--- a/moses/FF/SoftSourceSyntacticConstraintsFeature.cpp
+++ b/moses/FF/SoftSourceSyntacticConstraintsFeature.cpp
@@ -288,7 +288,7 @@ void SoftSourceSyntacticConstraintsFeature::EvaluateWithSourceContext(const Inpu
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore) const
+ , ScoreComponentCollection *estimatedScore) const
{
assert(stackVec);
diff --git a/moses/FF/SoftSourceSyntacticConstraintsFeature.h b/moses/FF/SoftSourceSyntacticConstraintsFeature.h
index 7540dad25..2ed059764 100644
--- a/moses/FF/SoftSourceSyntacticConstraintsFeature.h
+++ b/moses/FF/SoftSourceSyntacticConstraintsFeature.h
@@ -35,7 +35,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
targetPhrase.SetRuleSource(source);
};
@@ -44,7 +44,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const;
+ , ScoreComponentCollection *estimatedScore = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const
diff --git a/moses/FF/SourceGHKMTreeInputMatchFeature.cpp b/moses/FF/SourceGHKMTreeInputMatchFeature.cpp
index 9dae34ca2..8f87321a6 100644
--- a/moses/FF/SourceGHKMTreeInputMatchFeature.cpp
+++ b/moses/FF/SourceGHKMTreeInputMatchFeature.cpp
@@ -37,7 +37,7 @@ void SourceGHKMTreeInputMatchFeature::EvaluateWithSourceContext(const InputType
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore) const
+ , ScoreComponentCollection *estimatedScore) const
{
const Range& range = inputPath.GetWordsRange();
size_t startPos = range.GetStartPos();
diff --git a/moses/FF/SourceGHKMTreeInputMatchFeature.h b/moses/FF/SourceGHKMTreeInputMatchFeature.h
index 15f1877de..102fd059f 100644
--- a/moses/FF/SourceGHKMTreeInputMatchFeature.h
+++ b/moses/FF/SourceGHKMTreeInputMatchFeature.h
@@ -20,14 +20,14 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {};
+ , ScoreComponentCollection &estimatedScore) const {};
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const;
+ , ScoreComponentCollection *estimatedScore = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/SourceWordDeletionFeature.cpp b/moses/FF/SourceWordDeletionFeature.cpp
index 936a844f3..7e46ddabc 100644
--- a/moses/FF/SourceWordDeletionFeature.cpp
+++ b/moses/FF/SourceWordDeletionFeature.cpp
@@ -64,7 +64,7 @@ bool SourceWordDeletionFeature::IsUseable(const FactorMask &mask) const
void SourceWordDeletionFeature::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
const AlignmentInfo &alignmentInfo = targetPhrase.GetAlignTerm();
ComputeFeatures(source, targetPhrase, &scoreBreakdown, alignmentInfo);
diff --git a/moses/FF/SourceWordDeletionFeature.h b/moses/FF/SourceWordDeletionFeature.h
index 5ec87b21a..029520229 100644
--- a/moses/FF/SourceWordDeletionFeature.h
+++ b/moses/FF/SourceWordDeletionFeature.h
@@ -30,13 +30,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/SpanLength.cpp b/moses/FF/SpanLength.cpp
index afd15771b..aee9ffe63 100644
--- a/moses/FF/SpanLength.cpp
+++ b/moses/FF/SpanLength.cpp
@@ -24,7 +24,7 @@ SpanLength::SpanLength(const std::string &line)
void SpanLength::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
targetPhrase.SetRuleSource(source);
}
@@ -34,7 +34,7 @@ void SpanLength::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore) const
+ , ScoreComponentCollection *estimatedScore) const
{
assert(stackVec);
diff --git a/moses/FF/SpanLength.h b/moses/FF/SpanLength.h
index b3998e462..8fb749207 100644
--- a/moses/FF/SpanLength.h
+++ b/moses/FF/SpanLength.h
@@ -18,14 +18,14 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
virtual void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const;
+ , ScoreComponentCollection *estimatedScore = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/SparseHieroReorderingFeature.h b/moses/FF/SparseHieroReorderingFeature.h
index 1ea852c41..c6bf3d986 100644
--- a/moses/FF/SparseHieroReorderingFeature.h
+++ b/moses/FF/SparseHieroReorderingFeature.h
@@ -34,14 +34,14 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
virtual void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/SyntaxRHS.cpp b/moses/FF/SyntaxRHS.cpp
index a06477855..ce4ec4f42 100644
--- a/moses/FF/SyntaxRHS.cpp
+++ b/moses/FF/SyntaxRHS.cpp
@@ -17,7 +17,7 @@ SyntaxRHS::SyntaxRHS(const std::string &line)
void SyntaxRHS::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
}
@@ -26,7 +26,7 @@ void SyntaxRHS::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore) const
+ , ScoreComponentCollection *estimatedScore) const
{
assert(stackVec);
diff --git a/moses/FF/SyntaxRHS.h b/moses/FF/SyntaxRHS.h
index 46911ccd9..e864f4585 100644
--- a/moses/FF/SyntaxRHS.h
+++ b/moses/FF/SyntaxRHS.h
@@ -18,13 +18,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const;
+ , ScoreComponentCollection *estimatedScore = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/TargetBigramFeature.h b/moses/FF/TargetBigramFeature.h
index d63d71aca..738793a57 100644
--- a/moses/FF/TargetBigramFeature.h
+++ b/moses/FF/TargetBigramFeature.h
@@ -53,12 +53,12 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/TargetNgramFeature.h b/moses/FF/TargetNgramFeature.h
index d09618d14..8039971b4 100644
--- a/moses/FF/TargetNgramFeature.h
+++ b/moses/FF/TargetNgramFeature.h
@@ -220,7 +220,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -230,7 +230,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
void SetParameter(const std::string& key, const std::string& value);
diff --git a/moses/FF/TargetWordInsertionFeature.cpp b/moses/FF/TargetWordInsertionFeature.cpp
index 215fbf7a0..0bde0b92a 100644
--- a/moses/FF/TargetWordInsertionFeature.cpp
+++ b/moses/FF/TargetWordInsertionFeature.cpp
@@ -56,7 +56,7 @@ void TargetWordInsertionFeature::Load()
void TargetWordInsertionFeature::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
const AlignmentInfo &alignmentInfo = targetPhrase.GetAlignTerm();
ComputeFeatures(source, targetPhrase, &scoreBreakdown, alignmentInfo);
diff --git a/moses/FF/TargetWordInsertionFeature.h b/moses/FF/TargetWordInsertionFeature.h
index 77d009227..28943a023 100644
--- a/moses/FF/TargetWordInsertionFeature.h
+++ b/moses/FF/TargetWordInsertionFeature.h
@@ -30,13 +30,13 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateWhenApplied(const Hypothesis& hypo,
ScoreComponentCollection* accumulator) const {
diff --git a/moses/FF/TreeStructureFeature.h b/moses/FF/TreeStructureFeature.h
index cef87e7ee..fec3a1446 100644
--- a/moses/FF/TreeStructureFeature.h
+++ b/moses/FF/TreeStructureFeature.h
@@ -66,13 +66,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {};
+ , ScoreComponentCollection &estimatedScore) const {};
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {};
+ , ScoreComponentCollection *estimatedScore = NULL) const {};
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/UnalignedWordCountFeature.cpp b/moses/FF/UnalignedWordCountFeature.cpp
index 64ea36a72..720d9483f 100644
--- a/moses/FF/UnalignedWordCountFeature.cpp
+++ b/moses/FF/UnalignedWordCountFeature.cpp
@@ -21,7 +21,7 @@ UnalignedWordCountFeature::UnalignedWordCountFeature(const std::string &line)
void UnalignedWordCountFeature::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
const AlignmentInfo &alignmentInfo = targetPhrase.GetAlignTerm();
const size_t sourceLength = source.GetSize();
diff --git a/moses/FF/UnalignedWordCountFeature.h b/moses/FF/UnalignedWordCountFeature.h
index f0efbb70e..a229b3364 100644
--- a/moses/FF/UnalignedWordCountFeature.h
+++ b/moses/FF/UnalignedWordCountFeature.h
@@ -19,14 +19,14 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/UnknownWordPenaltyProducer.h b/moses/FF/UnknownWordPenaltyProducer.h
index 40233cb56..50b33177c 100644
--- a/moses/FF/UnknownWordPenaltyProducer.h
+++ b/moses/FF/UnknownWordPenaltyProducer.h
@@ -45,7 +45,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -55,7 +55,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
};
diff --git a/moses/FF/WordPenaltyProducer.cpp b/moses/FF/WordPenaltyProducer.cpp
index 835ee8e96..063a1c5f5 100644
--- a/moses/FF/WordPenaltyProducer.cpp
+++ b/moses/FF/WordPenaltyProducer.cpp
@@ -20,7 +20,7 @@ WordPenaltyProducer::WordPenaltyProducer(const std::string &line)
void WordPenaltyProducer::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const
+ , ScoreComponentCollection &estimatedScore) const
{
float score = - (float) targetPhrase.GetNumTerminals();
scoreBreakdown.Assign(this, score);
diff --git a/moses/FF/WordPenaltyProducer.h b/moses/FF/WordPenaltyProducer.h
index 5d4005533..fca021966 100644
--- a/moses/FF/WordPenaltyProducer.h
+++ b/moses/FF/WordPenaltyProducer.h
@@ -30,7 +30,7 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const;
+ , ScoreComponentCollection &estimatedScore) const;
void EvaluateWhenApplied(const Hypothesis& hypo,
ScoreComponentCollection* accumulator) const {
}
@@ -45,7 +45,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const {
+ , ScoreComponentCollection *estimatedScore = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/WordTranslationFeature.cpp b/moses/FF/WordTranslationFeature.cpp
index 88d0ef3a4..088b55e55 100644
--- a/moses/FF/WordTranslationFeature.cpp
+++ b/moses/FF/WordTranslationFeature.cpp
@@ -142,7 +142,7 @@ void WordTranslationFeature::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore) const
+ , ScoreComponentCollection *estimatedScore) const
{
const Sentence& sentence = static_cast<const Sentence&>(input);
const AlignmentInfo &alignment = targetPhrase.GetAlignTerm();
diff --git a/moses/FF/WordTranslationFeature.h b/moses/FF/WordTranslationFeature.h
index fee9cb668..accd5d594 100644
--- a/moses/FF/WordTranslationFeature.h
+++ b/moses/FF/WordTranslationFeature.h
@@ -47,12 +47,12 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const;
+ , ScoreComponentCollection *estimatedScore = NULL) const;
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedFutureScore) const {
+ , ScoreComponentCollection &estimatedScore) const {
}
void EvaluateWhenApplied(const Hypothesis& hypo,
diff --git a/moses/FF/FeatureFunction.h b/moses/FF/FeatureFunction.h
index 994e65498..5e01e7df6 100644
--- a/moses/FF/FeatureFunction.h
+++ b/moses/FF/FeatureFunction.h
@@ -151,7 +151,7 @@ public:
virtual void
EvaluateInIsolation(const Phrase &source, const TargetPhrase &targetPhrase,
ScoreComponentCollection& scoreBreakdown,
- ScoreComponentCollection& estimatedFutureScore) const = 0;
+ ScoreComponentCollection& estimatedScore) const = 0;
// for context-dependent processing
static void SetupAll(TranslationTask const& task);
@@ -163,13 +163,13 @@ public:
// 'stackVec' is a vector of chart cells that the RHS non-terms cover.
// It is guaranteed to be in the same order as the non-terms in the source phrase.
// For pb models, stackvec is NULL.
// No FF should set estimatedFutureScore in both overloads!
virtual void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedFutureScore = NULL) const = 0;
+ , ScoreComponentCollection *estimatedScore = NULL) const = 0;
// This method is called once all the translation options are retrieved from the phrase table, and
// just before search.
@@ -177,7 +177,7 @@ public:
// 'stackVec' is a vector of chart cells that the RHS non-terms cover.
// It is guaranteed to be in the same order as the non-terms in the source phrase.
// For pb models, stackvec is NULL.
// No FF should set estimatedFutureScore in both overloads!
virtual void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const = 0;
@@ -163,13 +163,13 @@ public:
// It is guaranteed to be in the same order as the non-terms in the source phrase.
// For pb models, stackvec is NULL.
- // No FF should set estimatedFutureScore in both overloads!
+ // No FF should set estimatedScore in both overloads!
virtual void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
@@ -177,7 +177,7 @@ public:
// It is guaranteed to be in the same order as the non-terms in the source phrase.
// For pb models, stackvec is NULL.
- // No FF should set estimatedFutureScore in both overloads!
+ // No FF should set estimatedScore in both overloads!
virtual void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const = 0;